aboutsummaryrefslogtreecommitdiffstats
path: root/os/hal/include/serial_usb.h
diff options
context:
space:
mode:
Diffstat (limited to 'os/hal/include/serial_usb.h')
-rw-r--r--os/hal/include/serial_usb.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/os/hal/include/serial_usb.h b/os/hal/include/serial_usb.h
index 28ab3a940..83aa4ec69 100644
--- a/os/hal/include/serial_usb.h
+++ b/os/hal/include/serial_usb.h
@@ -99,9 +99,9 @@
/* Derived constants and error checks. */
/*===========================================================================*/
-#if !HAL_USE_USB || !CH_USE_QUEUES || !CH_USE_EVENTS
-#error "Serial over USB Driver requires HAL_USE_USB, CH_USE_QUEUES, "
- "CH_USE_EVENTS"
+#if !HAL_USE_USB || !CH_CFG_USE_QUEUES || !CH_CFG_USE_EVENTS
+#error "Serial over USB Driver requires HAL_USE_USB, CH_CFG_USE_QUEUES, "
+ "CH_CFG_USE_EVENTS"
#endif
/*===========================================================================*/